import styles from './styles.module.css'
import Options from "../options";
import Arguments from "../arguments";
import {Provider} from "./context";
import {useEffect, useState} from "react";
import {CommandInterface} from "../../../../../api/sm/responses/comamnds";

interface CommandComponentInterface {
    command: CommandInterface,
    callback: any,
    optionsParams?: Record<string, any>,
    argumentsParams?: Record<string, any>,
}

export default function Command({command, callback, optionsParams, argumentsParams}: CommandComponentInterface) {
    const [optionList, setOptionList] = useState<Record<string, any>>(optionsParams || {});
    const [argumentList, setArgumentList] = useState<Record<string, any>>(argumentsParams || {});

    useEffect(() => {
        callback && callback(command.name, optionList, argumentList)
    }, [optionList, argumentList])

    return (
        <Provider value={{optionList, setOptionList, argumentList, setArgumentList}}>
            <div>
                <div title={command.description}>
                    <Options optionList={command.options} />
                    <Arguments argumentList={command.arguments} />
                </div>
            </div>
        </Provider>
    )
}
